@@ -780,7 +780,7 @@ class Objective:
                 'Base': DecisionTreeRegressor(
                     max_depth =  trial.suggest_int('_max_depth', 2, 100),
                     criterion = trial.suggest_categorical('_criterion', ['mse', 'friedman_mse']),
-                    # random_state = self.rng,
+                    random_state = self.rng,
                 ),
                 'n_estimators' : trial.suggest_int('n_estimators', 10, 1000, log=True),
                 'minibatch_frac': trial.suggest_uniform('minibatch_frac', 0.5, 1.0),
@@ -812,7 +812,7 @@ class Objective:
                 clone(self.estimator_), self.X, self.y, self.scoring, train, test, 0, dict(**self.fixed_params_, **params_), None
             )
         for train, test in self.cv.split(self.X, self.y))
-        return np.mean([d['test_scores'] for d in results])
+        return np.mean([d['test_scores'] for d in results]) # scikit-learn>=0.24.1
 
     def get_best_estimator(self, study):
         best_params_ = self.get_best_params(study)
@@ -828,8 +828,8 @@ class Objective:
                 else:
                     best_params_[k] = v
             else:
-                # if 'random_state' in self.fixed_params_:
-                #     dt_best_params_['random_state'] = self.fixed_params_['random_state']
+                if 'random_state' in self.fixed_params_:
+                    dt_best_params_['random_state'] = self.fixed_params_['random_state']
                 best_params_['Base'] = DecisionTreeRegressor(**dt_best_params_)
         else:
             best_params_ = study.best_params
